@@ -36,6 +36,14 @@ class ICommunicationService(ABC):
     async def send_data(self, robot_name: str, channel_id: int, pdu_data: bytearray) -> bool:
         pass
 
+    @abstractmethod
+    async def send_binary(self, raw_data: bytearray) -> bool:
+        pass
+
+    @abstractmethod
+    def register_event_handler(self, handler: callable):
+        pass
+
     @abstractmethod
     async def send_data_nowait(self, robot_name: str, channel_id: int, pdu_data: bytearray) -> bool:
         pass
